# $Id: SimpleTagParser.pm,v 1.7 2011-04-14 15:16:22 th Exp $

package TransLog::SimpleTagParser;

use warnings;
use strict;
require Digest::MD5;

# use CVS/RCS Revision tag to set up the package version
our $VERSION = do { my @r = (q$Revision: 1.7 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };

my $logFile = "";
my %tags = ();

sub _parseTags {
    my ($self) = @_;
    my $endOfHeadersReached = 0;
    open(FILE, "<$logFile") or die "Can't open '$logFile': $!";
    my $lastKey = '';
    while (my $line = <FILE>){
      if ($endOfHeadersReached == 0){
        chomp $line;
        if ( $line =~ m/^\s*$/ ) {
          #print "end of headers reached\n";
          $endOfHeadersReached++;
        } elsif ( $line =~ m/(.*?):(\s+(.+))?/ ){
          my $key = $1;
          $key = lc($key);
          chomp $key;
          $key =~ s/\s+//g;
          $lastKey = $key;
          my $value = "";
          if (defined $3) { 
            $value = $3; 
            chomp $value;
            $value =~ s/#.*//; # remove possible comments from value
            $value =~ s/\s+/ /g; # remove multiple whitespaces
            $value =~ s/^\s+//; # remove leading whitespaces
            $value =~ s/\s+$//; # remove trailing whitespaces
            if ( ! hasTag($key) ) {
              $tags{$key} = $value;
            } else {
              warn "tag $key already known in $logFile";
            }
          }
        } elsif ( $lastKey ne "" && $line =~ m/\s+(.+)/ ) {
          # found a multiline entry
          # append value to previous key 
          my $value = $1;
          my $oldValue = $tags{$lastKey};
          $tags{$lastKey} = $oldValue . "\n      " . $value;
        } else {
          warn ("unexpected line found in $logFile: $line");
        }
      } 
    }
    close(FILE);
}

##
# @return a new base object
sub new {
    my ($class, $log) = @_;
    my $self = {};
    $logFile = $log;
    bless ($self,$class);

    $logFile = $log;
    %tags = ();
    _parseTags();

    return $self;
}

sub getFilename {
    my ($self) = @_;
    return $logFile;
}

# @return ...
sub hasTag {
    my ($self, $key) = @_;
    return exists($tags{lc($key)});
}

# @return
sub getTag {
    my ($self, $key) = @_;
    return $tags{lc($key)};
}

# guess which OS the "Betriebssystem"-Tag describes
sub guessOS {
  my ($self, $betriebssystem) = @_;
  my $os = "unable to guess operating System!";
  chomp($betriebssystem);
  if ( $betriebssystem =~ m/Linux\s+2.4.27/ ){
    $os = "Debian Woody";
  } elsif (( $betriebssystem =~ m/Linux\s+2.6.(18|24)-\d+-(amd64|686)/ ) ||
           ( $betriebssystem =~ m/Linux\s+2.6.(18|24)-openvz.*(amd64|686)/ )) {
    $os = "Debian Etch";
  } elsif (( $betriebssystem =~ m/Linux\s+2.6.26-\d+-(amd64|686)/ ) ||
           ( $betriebssystem =~ m/Linux\s+2.6.26-\d+-openvz.*(amd64|686)/ )) {
    $os = "Debian Lenny";
  } elsif (( $betriebssystem =~ m/Linux\s+2.6.32-\d+-(amd64|686)/ ) ||
           ( $betriebssystem =~ m/Linux\s+2.6.32-\d+-openvz.*(amd64|686)/ )) {
    $os = "Debian Squeeze";
  } elsif ( $betriebssystem =~ m/Linux\s+2.6.32-\d+-server\s+(686|x86_64)/ ) {
    $os = "Ubuntu 10.04";
} elsif ( $betriebssystem =~ m/Linux\s+2.6.18-\d+\.el5\s+(686|x86_64)/ ) {
    $os = "RHEL5";
  } elsif ( $betriebssystem =~ m/FreeBSD\s+6\..*/ ){
    $os = "FreeBSD 6.x";
  } elsif ( $betriebssystem =~ m/FreeBSD\s+5\..*/ ){
    $os = "FreeBSD 5.x";
  } elsif ( $betriebssystem =~ m/FreeBSD\s+4\..*/ ){
    $os = "FreeBSD 4.x";
  }
  return $os;
}


1;

# vim: ai et ts=2 shiftwidth=2
