# $Id: functions.pm,v 1.9 2010-08-16 08:58:24 th Exp $

package TransLog::bacula::functions;

use warnings;
use strict;
use FindBin;

# use CVS/RCS Revision tag to set up the package version
our $VERSION = do { my @r = (q$Revision: 1.9 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };

sub getClientsFromBacula {
  my ($host) = @_;

  # connect to backup.lf.net and fetch the list of active clients
  my $liststr = `(echo stat; echo 3; echo .; echo quit) | ssh $host bconsole`;

  # remove unmwanted output
  $liststr =~ s/^.*The\sdefined\sClient\sresources\sare:\n//s;
  $liststr =~ s/Select\sClient\s\(File\sdaemon\).*$//s;
  my @list = split(/\n/, $liststr);

  # fetch only valid client entries from list
  my @clients = ();
  foreach my $elem (@list){
    chomp $elem;
    if ( $elem =~ m/\s+\d+:\s+(.*)-fd/ ){
      my $client = $1;
      push(@clients,$client);
    } else {
      warn "unexpected output found: $elem";
    }
  }
  return @clients;
} # end sub

sub saveClientsToFile {
    my ($filename,@clients) = @_;
    print "writing client list to $filename: ";
    TransLog::base::writeArrayToFile($TransLog::config::localstatedir . 
				     "/".$filename, @clients);
    print " done\n";
} # end sub

# convert the given Logfile to xml syntax
# corresponding backup.dtd
sub log2xml {
    my ($logFile,$sparser) = @_;

    # is this a JAIL Log file ?
    my $jail = "";
    if ($sparser->hasTag("JAIL.Hostname")) { $jail = "JAIL."; }
   
    my $dtddir = "$FindBin::Bin/../share/perl5/TransLog/dtd";
    my $xml = "";
    $xml.= '<?xml version="1.0" encoding="iso-8859-1" standalone="no" ?>'."\n";
    $xml.= '<!DOCTYPE server SYSTEM "file://'.$dtddir.'/backup.dtd">'."\n";
    $xml.= "<server>\n";
    $xml.= "  <hostname>".lc($sparser->getTag($jail . "hostname"))."</hostname>\n";
    $xml.= "  <betriebssystem>".$sparser->getTag("betriebssystem")
           ."</betriebssystem>\n";
    $xml.= "  <betriebssystemname>"
           .$sparser->guessOS($sparser->getTag("betriebssystem"))
           ."</betriebssystemname>\n";
    use Cwd 'realpath';
    my $realpath = realpath($logFile);
    $xml.= "  <logsource>".$realpath."</logsource>\n";
    my ($dev,$ino,$mode,$nlink,$uid,$gid,$rdev,$size,
	$atime,$mtime,$ctime,$blksize,$blocks)
	= stat($logFile);
    $xml.= "  <modified>".$mtime."</modified>\n";
    use POSIX qw(strftime);
    # RFC822 (actually RFC2822, as the year has 4 digits)
    my $rfc822mtime = strftime("%a, %d %b %Y %H:%M:%S %z", localtime($mtime));
    $xml.= "  <modified-rfc822>".$rfc822mtime."</modified-rfc822>\n";
    $xml.= "  <backup>\n";
    $xml.= "    <type>".$sparser->getTag("Check.backup")."</type>\n";
    $xml.= "    <password>".$sparser->getTag("Backup.PSK")."</password>\n";
    $xml.= "    <fileset>Standard-Fileset20121026</fileset>\n";
    $xml.= "  </backup>\n";
    $xml.= "</server>\n";
    return $xml;
} # end sub

# vim: ai et ts=2 shiftwidth=2
